"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usingFetch = exports.usingAjax = exports.loadCss = void 0;
/**
 * dynamic load style
 *
 * @param path style path
 */
function loadCss(path, options) {
    const attributes = options !== null && options !== void 0 ? options : {};
    return new Promise((resolve, reject) => {
        const style = document.createElement('link');
        for (const key in attributes) {
            // script.setAttribute(key, attributes[key]);
            style[key] = attributes[key];
        }
        style.rel = 'stylesheet';
        style.href = path;
        style.onerror = reject;
        style.onload = () => {
            // style.parentNode.removeChild(style);
            resolve();
        };
        document.head.appendChild(style);
    });
}
exports.loadCss = loadCss;
/**
 * dynamic load script using ajax
 *
 * @param path script path
 */
function usingAjax(path) {
    return new Promise((resolve, reject) => {
        const xhr = new XMLHttpRequest();
        xhr.onreadystatechange = function () {
            if (xhr.readyState === 4) {
                const style = document.createElement('style');
                style.innerText = xhr.responseText;
                style.onerror = reject;
                // style.onload = () => {
                //   // style.parentNode.removeChild(style);
                //   resolve();
                // };
                document.head.appendChild(style);
                setTimeout(resolve, 0);
            }
        };
        xhr.onerror = reject;
        xhr.open('GET', path);
        xhr.send();
    });
}
exports.usingAjax = usingAjax;
/**
 * dynamic load script using fetch
 *
 * @param path script path
 */
function usingFetch(path) {
    return new Promise((resolve, reject) => fetch(path)
        .then((res) => res.text())
        .then((styleText) => {
        const style = document.createElement('style');
        style.innerText = styleText;
        style.onerror = reject;
        // style.onload = () => {
        //   // style.parentNode.removeChild(style);
        //   resolve();
        // };
        document.head.appendChild(style);
        setTimeout(resolve, 0);
    }));
}
exports.usingFetch = usingFetch;
exports.default = loadCss;
